![](https://res.cloudinary.com/dmuligbfy/image/upload/c_scale,r_25,w_150/Crawfish/crawfish.png)

# Django Crawfish
![PyPI - License](https://img.shields.io/pypi/l/django-crawfish)
![PyPI](https://img.shields.io/pypi/v/django-crawfish)
![Gitlab pipeline status](https://img.shields.io/gitlab/pipeline/crawfordleeds/crawfish)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-crawfish)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-crawfish)
![pipeline status](https://gitlab.com/crawfordleeds/crawfish/badges/master/pipeline.svg)

[![coverage report](https://gitlab.com/crawfordleeds/crawfish/badges/master/coverage.svg)](https://gitlab.com/crawfordleeds/crawfish/-/commits/master)
[![Codecov](https://img.shields.io/codecov/c/gl/crawfordleeds/crawfish?label=Codecov%20Coverage)](https://codecov.io/gl/crawfordleeds/crawfish/)

This project contains a collection of code I re-use for most of my Django projects and is not [yet] well suited
for public consumption.

## Documentation

[https://crawfish.readthedocs.io/en/latest](https://crawfish.readthedocs.io/en/latest)

### Installation

```bash
pip install django-crawfish
```

## Development

Install package dependencies:

```bash
pip install -e .
```

Install dev dependencies:

```bash
pip install -e '.[dev]'
```

Run tests:

```bash
python runtests.py

```
